@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from Quartz.QuartzCore import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestCATextLayer (TestCase):
 
     @min_os_level('10.5')
@@ -14,6 +9,11 @@ class TestCATextLayer (TestCase):
         self.assertResultIsBOOL(CATextLayer.isWrapped)
         self.assertArgIsBOOL(CATextLayer.setWrapped_, 0)
 
+    @min_os_level('10.11')
+    def testMethods10_11(self):
+        self.assertResultIsBOOL(CATextLayer.allowsFontSubpixelQuantization)
+        self.assertArgIsBOOL(CATextLayer.setAllowsFontSubpixelQuantization_, 0)
+
     @min_os_level('10.5')
     def testConstants(self):
         self.assertIsInstance(kCATruncationNone, unicode)
