@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from Quartz.QuartzCore import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestCIFilterGenerator (TestCase):
     def testConstants(self):
         self.assertIsInstance(kCIFilterGeneratorExportedKey, unicode)
