@@ -2,22 +2,14 @@
 from PyObjCTools.TestSupport import *
 from Quartz import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestCVImageBuffer (TestCase):
 
-    def testFunctions(self):
-        self.assertResultHasType(CVImageBufferGetEncodedSize, CGSize.__typestr__)
-        self.assertResultHasType(CVImageBufferGetDisplaySize, CGSize.__typestr__)
-        self.assertResultHasType(CVImageBufferGetCleanRect, CGRect.__typestr__)
 
     @expectedFailure
     def testsMissing(self):
         # FIXME
         CVImageBufferGetColorSpace
+        CVImageBufferRef
         self.fail("Reimplement function tests using an actual buffer")
 
     def testConstants(self):
@@ -82,9 +74,56 @@ class TestCVImageBuffer (TestCase):
     def testConstants10_8(self):
         self.assertIsInstance(kCVImageBufferColorPrimaries_P22, unicode)
 
+    @min_os_level('10.10')
+    def testConstants10_10(self):
+        self.assertIsInstance(kCVImageBufferAlphaChannelIsOpaque, unicode)
+
+    @min_os_level('10.11')
+    def testConstants10_11(self):
+        self.assertIsInstance(kCVImageBufferYCbCrMatrix_ITU_R_2020, unicode)
+
+        self.assertIsInstance(kCVImageBufferColorPrimaries_DCI_P3, unicode)
+        self.assertIsInstance(kCVImageBufferColorPrimaries_P3_D65, unicode)
+        self.assertIsInstance(kCVImageBufferColorPrimaries_ITU_R_2020, unicode)
+
+        self.assertIsInstance(kCVImageBufferTransferFunction_ITU_R_2020, unicode)
+
+    @min_os_level('10.12')
+    def testConstants10_12(self):
+        self.assertIsInstance(kCVImageBufferTransferFunction_SMPTE_ST_428_1, unicode)
+
+    @min_os_level('10.13')
+    def testConstants10_13(self):
+        self.assertIsInstance(kCVImageBufferTransferFunction_SMPTE_ST_2084_PQ, unicode)
+        self.assertIsInstance(kCVImageBufferTransferFunction_ITU_R_2100_HLG, unicode)
+        self.assertIsInstance(kCVImageBufferMasteringDisplayColorVolumeKey, unicode)
+        self.assertIsInstance(kCVImageBufferContentLightLevelInfoKey, unicode)
+        self.assertIsInstance(kCVMetalTextureUsage, unicode)
+        self.assertIsInstance(kCVImageBufferTransferFunction_sRGB, unicode)
+
+    @min_os_level('10.14')
+    def testConstants10_14(self):
+        self.assertIsInstance(kCVImageBufferTransferFunction_Linear, unicode)
+
+    def testFunctions(self):
+        self.assertResultHasType(CVImageBufferGetEncodedSize, CGSize.__typestr__)
+        self.assertResultHasType(CVImageBufferGetDisplaySize, CGSize.__typestr__)
+        self.assertResultHasType(CVImageBufferGetCleanRect, CGRect.__typestr__)
+        self.assertResultHasType(CVImageBufferIsFlipped, objc._C_NSBOOL)
+
     @min_os_level('10.8')
     def testFunctions10_8(self):
         self.assertResultIsCFRetained(CVImageBufferCreateColorSpaceFromAttachments)
 
+    @min_os_level('10.13')
+    def testFunctions10_13(self):
+        CVYCbCrMatrixGetIntegerCodePointForString
+        CVColorPrimariesGetIntegerCodePointForString
+        CVTransferFunctionGetIntegerCodePointForString
+        CVYCbCrMatrixGetStringForIntegerCodePoint
+        CVColorPrimariesGetStringForIntegerCodePoint
+        CVTransferFunctionGetStringForIntegerCodePoint
+
+
 if __name__ == "__main__":
     main()
