@@ -24,13 +24,18 @@ class TestIKCameraDeviceView (TestCase):
 
         self.assertResultIsBOOL(IKCameraDeviceView.displaysPostProcessApplicationControl)
         self.assertArgIsBOOL(IKCameraDeviceView.setDisplaysPostProcessApplicationControl_, 0)
+
         self.assertResultIsBOOL(IKCameraDeviceView.canRotateSelectedItemsLeft)
         self.assertResultIsBOOL(IKCameraDeviceView.canRotateSelectedItemsRight)
         self.assertResultIsBOOL(IKCameraDeviceView.canDeleteSelectedItems)
-        self.assertResultIsBOOL(IKCameraDeviceView.canDeleteSelectedItems)
-
+        self.assertResultIsBOOL(IKCameraDeviceView.canDownloadSelectedItems)
 
         self.assertArgIsBOOL(IKCameraDeviceView.selectIndexes_byExtendingSelection_, 1)
+    
+    @min_sdk_level('10.10')
+    def testProtocols(self):
+	# XXX: Require minimal deployment target of 10.6
+        objc.protocolNamed('IKCameraDeviceViewDelegate')
 
 if __name__ == "__main__":
     main()
